# TagIn


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 

## Example

```python
from core.v2.models.tag_in import TagIn

# TODO update the JSON string below
json = "{}"
# create an instance of TagIn from a JSON string
tag_in_instance = TagIn.from_json(json)
# print the JSON string representation of the object
print(TagIn.to_json())

# convert the object into a dict
tag_in_dict = tag_in_instance.to_dict()
# create an instance of TagIn from a dict
tag_in_from_dict = TagIn.from_dict(tag_in_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


